import type { BaseContract, BigNumber, BigNumberish, BytesLike, CallOverrides, PopulatedTransaction, Signer, utils } from "ethers";
import type { FunctionFragment, Result } from "@ethersproject/abi";
import type { Listener, Provider } from "@ethersproject/providers";
import type { TypedEventFilter, TypedEvent, TypedListener, OnEvent, PromiseOrValue } from "./common";
export declare namespace NFTBridgeStorage {
    type SPLCacheStruct = {
        name: PromiseOrValue<BytesLike>;
        symbol: PromiseOrValue<BytesLike>;
    };
    type SPLCacheStructOutput = [string, string] & {
        name: string;
        symbol: string;
    };
}
export interface NFTBridgeGettersInterface extends utils.Interface {
    functions: {
        "bridgeContracts(uint16)": FunctionFragment;
        "chainId()": FunctionFragment;
        "evmChainId()": FunctionFragment;
        "finality()": FunctionFragment;
        "governanceActionIsConsumed(bytes32)": FunctionFragment;
        "governanceChainId()": FunctionFragment;
        "governanceContract()": FunctionFragment;
        "isFork()": FunctionFragment;
        "isInitialized(address)": FunctionFragment;
        "isTransferCompleted(bytes32)": FunctionFragment;
        "isWrappedAsset(address)": FunctionFragment;
        "splCache(uint256)": FunctionFragment;
        "tokenImplementation()": FunctionFragment;
        "wormhole()": FunctionFragment;
        "wrappedAsset(uint16,bytes32)": FunctionFragment;
    };
    getFunction(nameOrSignatureOrTopic: "bridgeContracts" | "chainId" | "evmChainId" | "finality" | "governanceActionIsConsumed" | "governanceChainId" | "governanceContract" | "isFork" | "isInitialized" | "isTransferCompleted" | "isWrappedAsset" | "splCache" | "tokenImplementation" | "wormhole" | "wrappedAsset"): FunctionFragment;
    encodeFunctionData(functionFragment: "bridgeContracts", values: [PromiseOrValue<BigNumberish>]): string;
    encodeFunctionData(functionFragment: "chainId", values?: undefined): string;
    encodeFunctionData(functionFragment: "evmChainId", values?: undefined): string;
    encodeFunctionData(functionFragment: "finality", values?: undefined): string;
    encodeFunctionData(functionFragment: "governanceActionIsConsumed", values: [PromiseOrValue<BytesLike>]): string;
    encodeFunctionData(functionFragment: "governanceChainId", values?: undefined): string;
    encodeFunctionData(functionFragment: "governanceContract", values?: undefined): string;
    encodeFunctionData(functionFragment: "isFork", values?: undefined): string;
    encodeFunctionData(functionFragment: "isInitialized", values: [PromiseOrValue<string>]): string;
    encodeFunctionData(functionFragment: "isTransferCompleted", values: [PromiseOrValue<BytesLike>]): string;
    encodeFunctionData(functionFragment: "isWrappedAsset", values: [PromiseOrValue<string>]): string;
    encodeFunctionData(functionFragment: "splCache", values: [PromiseOrValue<BigNumberish>]): string;
    encodeFunctionData(functionFragment: "tokenImplementation", values?: undefined): string;
    encodeFunctionData(functionFragment: "wormhole", values?: undefined): string;
    encodeFunctionData(functionFragment: "wrappedAsset", values: [PromiseOrValue<BigNumberish>, PromiseOrValue<BytesLike>]): string;
    decodeFunctionResult(functionFragment: "bridgeContracts", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "chainId", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "evmChainId", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "finality", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "governanceActionIsConsumed", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "governanceChainId", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "governanceContract", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "isFork", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "isInitialized", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "isTransferCompleted", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "isWrappedAsset", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "splCache", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "tokenImplementation", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "wormhole", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "wrappedAsset", data: BytesLike): Result;
    events: {};
}
export interface NFTBridgeGetters extends BaseContract {
    connect(signerOrProvider: Signer | Provider | string): this;
    attach(addressOrName: string): this;
    deployed(): Promise<this>;
    interface: NFTBridgeGettersInterface;
    queryFilter<TEvent extends TypedEvent>(event: TypedEventFilter<TEvent>, fromBlockOrBlockhash?: string | number | undefined, toBlock?: string | number | undefined): Promise<Array<TEvent>>;
    listeners<TEvent extends TypedEvent>(eventFilter?: TypedEventFilter<TEvent>): Array<TypedListener<TEvent>>;
    listeners(eventName?: string): Array<Listener>;
    removeAllListeners<TEvent extends TypedEvent>(eventFilter: TypedEventFilter<TEvent>): this;
    removeAllListeners(eventName?: string): this;
    off: OnEvent<this>;
    on: OnEvent<this>;
    once: OnEvent<this>;
    removeListener: OnEvent<this>;
    functions: {
        bridgeContracts(chainId_: PromiseOrValue<BigNumberish>, overrides?: CallOverrides): Promise<[string]>;
        chainId(overrides?: CallOverrides): Promise<[number]>;
        evmChainId(overrides?: CallOverrides): Promise<[BigNumber]>;
        finality(overrides?: CallOverrides): Promise<[number]>;
        governanceActionIsConsumed(hash: PromiseOrValue<BytesLike>, overrides?: CallOverrides): Promise<[boolean]>;
        governanceChainId(overrides?: CallOverrides): Promise<[number]>;
        governanceContract(overrides?: CallOverrides): Promise<[string]>;
        isFork(overrides?: CallOverrides): Promise<[boolean]>;
        isInitialized(impl: PromiseOrValue<string>, overrides?: CallOverrides): Promise<[boolean]>;
        isTransferCompleted(hash: PromiseOrValue<BytesLike>, overrides?: CallOverrides): Promise<[boolean]>;
        isWrappedAsset(token: PromiseOrValue<string>, overrides?: CallOverrides): Promise<[boolean]>;
        splCache(tokenId: PromiseOrValue<BigNumberish>, overrides?: CallOverrides): Promise<[NFTBridgeStorage.SPLCacheStructOutput]>;
        tokenImplementation(overrides?: CallOverrides): Promise<[string]>;
        wormhole(overrides?: CallOverrides): Promise<[string]>;
        wrappedAsset(tokenChainId: PromiseOrValue<BigNumberish>, tokenAddress: PromiseOrValue<BytesLike>, overrides?: CallOverrides): Promise<[string]>;
    };
    bridgeContracts(chainId_: PromiseOrValue<BigNumberish>, overrides?: CallOverrides): Promise<string>;
    chainId(overrides?: CallOverrides): Promise<number>;
    evmChainId(overrides?: CallOverrides): Promise<BigNumber>;
    finality(overrides?: CallOverrides): Promise<number>;
    governanceActionIsConsumed(hash: PromiseOrValue<BytesLike>, overrides?: CallOverrides): Promise<boolean>;
    governanceChainId(overrides?: CallOverrides): Promise<number>;
    governanceContract(overrides?: CallOverrides): Promise<string>;
    isFork(overrides?: CallOverrides): Promise<boolean>;
    isInitialized(impl: PromiseOrValue<string>, overrides?: CallOverrides): Promise<boolean>;
    isTransferCompleted(hash: PromiseOrValue<BytesLike>, overrides?: CallOverrides): Promise<boolean>;
    isWrappedAsset(token: PromiseOrValue<string>, overrides?: CallOverrides): Promise<boolean>;
    splCache(tokenId: PromiseOrValue<BigNumberish>, overrides?: CallOverrides): Promise<NFTBridgeStorage.SPLCacheStructOutput>;
    tokenImplementation(overrides?: CallOverrides): Promise<string>;
    wormhole(overrides?: CallOverrides): Promise<string>;
    wrappedAsset(tokenChainId: PromiseOrValue<BigNumberish>, tokenAddress: PromiseOrValue<BytesLike>, overrides?: CallOverrides): Promise<string>;
    callStatic: {
        bridgeContracts(chainId_: PromiseOrValue<BigNumberish>, overrides?: CallOverrides): Promise<string>;
        chainId(overrides?: CallOverrides): Promise<number>;
        evmChainId(overrides?: CallOverrides): Promise<BigNumber>;
        finality(overrides?: CallOverrides): Promise<number>;
        governanceActionIsConsumed(hash: PromiseOrValue<BytesLike>, overrides?: CallOverrides): Promise<boolean>;
        governanceChainId(overrides?: CallOverrides): Promise<number>;
        governanceContract(overrides?: CallOverrides): Promise<string>;
        isFork(overrides?: CallOverrides): Promise<boolean>;
        isInitialized(impl: PromiseOrValue<string>, overrides?: CallOverrides): Promise<boolean>;
        isTransferCompleted(hash: PromiseOrValue<BytesLike>, overrides?: CallOverrides): Promise<boolean>;
        isWrappedAsset(token: PromiseOrValue<string>, overrides?: CallOverrides): Promise<boolean>;
        splCache(tokenId: PromiseOrValue<BigNumberish>, overrides?: CallOverrides): Promise<NFTBridgeStorage.SPLCacheStructOutput>;
        tokenImplementation(overrides?: CallOverrides): Promise<string>;
        wormhole(overrides?: CallOverrides): Promise<string>;
        wrappedAsset(tokenChainId: PromiseOrValue<BigNumberish>, tokenAddress: PromiseOrValue<BytesLike>, overrides?: CallOverrides): Promise<string>;
    };
    filters: {};
    estimateGas: {
        bridgeContracts(chainId_: PromiseOrValue<BigNumberish>, overrides?: CallOverrides): Promise<BigNumber>;
        chainId(overrides?: CallOverrides): Promise<BigNumber>;
        evmChainId(overrides?: CallOverrides): Promise<BigNumber>;
        finality(overrides?: CallOverrides): Promise<BigNumber>;
        governanceActionIsConsumed(hash: PromiseOrValue<BytesLike>, overrides?: CallOverrides): Promise<BigNumber>;
        governanceChainId(overrides?: CallOverrides): Promise<BigNumber>;
        governanceContract(overrides?: CallOverrides): Promise<BigNumber>;
        isFork(overrides?: CallOverrides): Promise<BigNumber>;
        isInitialized(impl: PromiseOrValue<string>, overrides?: CallOverrides): Promise<BigNumber>;
        isTransferCompleted(hash: PromiseOrValue<BytesLike>, overrides?: CallOverrides): Promise<BigNumber>;
        isWrappedAsset(token: PromiseOrValue<string>, overrides?: CallOverrides): Promise<BigNumber>;
        splCache(tokenId: PromiseOrValue<BigNumberish>, overrides?: CallOverrides): Promise<BigNumber>;
        tokenImplementation(overrides?: CallOverrides): Promise<BigNumber>;
        wormhole(overrides?: CallOverrides): Promise<BigNumber>;
        wrappedAsset(tokenChainId: PromiseOrValue<BigNumberish>, tokenAddress: PromiseOrValue<BytesLike>, overrides?: CallOverrides): Promise<BigNumber>;
    };
    populateTransaction: {
        bridgeContracts(chainId_: PromiseOrValue<BigNumberish>, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        chainId(overrides?: CallOverrides): Promise<PopulatedTransaction>;
        evmChainId(overrides?: CallOverrides): Promise<PopulatedTransaction>;
        finality(overrides?: CallOverrides): Promise<PopulatedTransaction>;
        governanceActionIsConsumed(hash: PromiseOrValue<BytesLike>, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        governanceChainId(overrides?: CallOverrides): Promise<PopulatedTransaction>;
        governanceContract(overrides?: CallOverrides): Promise<PopulatedTransaction>;
        isFork(overrides?: CallOverrides): Promise<PopulatedTransaction>;
        isInitialized(impl: PromiseOrValue<string>, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        isTransferCompleted(hash: PromiseOrValue<BytesLike>, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        isWrappedAsset(token: PromiseOrValue<string>, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        splCache(tokenId: PromiseOrValue<BigNumberish>, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        tokenImplementation(overrides?: CallOverrides): Promise<PopulatedTransaction>;
        wormhole(overrides?: CallOverrides): Promise<PopulatedTransaction>;
        wrappedAsset(tokenChainId: PromiseOrValue<BigNumberish>, tokenAddress: PromiseOrValue<BytesLike>, overrides?: CallOverrides): Promise<PopulatedTransaction>;
    };
}
