"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.stringifyWormholeRelayerInfo = exports.printWormholeRelayerInfo = exports.getWormholeRelayerInfo = exports.getPrice = exports.getPriceAndRefundInfo = void 0;
const __1 = require("../..");
const ethers_1 = require("ethers");
const consts_1 = require("../consts");
const structs_1 = require("../structs");
const helpers_1 = require("./helpers");
function getPriceAndRefundInfo(sourceChain, targetChain, gasAmount, optionalParams) {
    return __awaiter(this, void 0, void 0, function* () {
        const environment = (optionalParams === null || optionalParams === void 0 ? void 0 : optionalParams.environment) || "MAINNET";
        const sourceChainProvider = (optionalParams === null || optionalParams === void 0 ? void 0 : optionalParams.sourceChainProvider) ||
            helpers_1.getDefaultProvider(environment, sourceChain);
        if (!sourceChainProvider)
            throw Error("No default RPC for this chain; pass in your own provider (as sourceChainProvider)");
        const wormholeRelayerAddress = (optionalParams === null || optionalParams === void 0 ? void 0 : optionalParams.wormholeRelayerAddress) ||
            consts_1.getWormholeRelayerAddress(sourceChain, environment);
        const sourceWormholeRelayer = __1.ethers_contracts.IWormholeRelayer__factory.connect(wormholeRelayerAddress, sourceChainProvider);
        const deliveryProviderAddress = (optionalParams === null || optionalParams === void 0 ? void 0 : optionalParams.deliveryProviderAddress) ||
            (yield sourceWormholeRelayer.getDefaultDeliveryProvider());
        const targetChainId = __1.CHAINS[targetChain];
        const priceAndRefundInfo = yield sourceWormholeRelayer["quoteEVMDeliveryPrice(uint16,uint256,uint256,address)"](targetChainId, (optionalParams === null || optionalParams === void 0 ? void 0 : optionalParams.receiverValue) || 0, gasAmount, deliveryProviderAddress);
        return priceAndRefundInfo;
    });
}
exports.getPriceAndRefundInfo = getPriceAndRefundInfo;
function getPrice(sourceChain, targetChain, gasAmount, optionalParams) {
    return __awaiter(this, void 0, void 0, function* () {
        const priceAndRefundInfo = yield getPriceAndRefundInfo(sourceChain, targetChain, gasAmount, optionalParams);
        return priceAndRefundInfo[0];
    });
}
exports.getPrice = getPrice;
function getWormholeRelayerInfo(sourceChain, sourceTransaction, infoRequest) {
    var _a, _b, _c, _d;
    return __awaiter(this, void 0, void 0, function* () {
        const environment = (infoRequest === null || infoRequest === void 0 ? void 0 : infoRequest.environment) || "MAINNET";
        const sourceChainProvider = (infoRequest === null || infoRequest === void 0 ? void 0 : infoRequest.sourceChainProvider) ||
            helpers_1.getDefaultProvider(environment, sourceChain);
        if (!sourceChainProvider)
            throw Error("No default RPC for this chain; pass in your own provider (as sourceChainProvider)");
        const receipt = yield sourceChainProvider.getTransactionReceipt(sourceTransaction);
        if (!receipt)
            throw Error("Transaction has not been mined");
        const bridgeAddress = __1.CONTRACTS[environment][sourceChain].core;
        const wormholeRelayerAddress = ((_a = infoRequest === null || infoRequest === void 0 ? void 0 : infoRequest.wormholeRelayerAddresses) === null || _a === void 0 ? void 0 : _a.get(sourceChain)) ||
            consts_1.getWormholeRelayerAddress(sourceChain, environment);
        if (!bridgeAddress || !wormholeRelayerAddress) {
            throw Error(`Invalid chain ID or network: Chain ${sourceChain}, ${environment}`);
        }
        const deliveryLog = helpers_1.getWormholeRelayerLog(receipt, bridgeAddress, __1.tryNativeToHexString(wormholeRelayerAddress, "ethereum"), (infoRequest === null || infoRequest === void 0 ? void 0 : infoRequest.wormholeRelayerWhMessageIndex)
            ? infoRequest.wormholeRelayerWhMessageIndex
            : 0);
        const { type, parsed } = helpers_1.parseWormholeLog(deliveryLog.log);
        const instruction = parsed;
        const targetChainId = instruction.targetChainId;
        if (!__1.isChain(targetChainId))
            throw Error(`Invalid Chain: ${targetChainId}`);
        const targetChain = __1.CHAIN_ID_TO_NAME[targetChainId];
        const targetChainProvider = ((_b = infoRequest === null || infoRequest === void 0 ? void 0 : infoRequest.targetChainProviders) === null || _b === void 0 ? void 0 : _b.get(targetChain)) ||
            helpers_1.getDefaultProvider(environment, targetChain);
        if (!targetChainProvider) {
            throw Error("No default RPC for this chain; pass in your own provider (as targetChainProvider)");
        }
        const [blockStartNumber, blockEndNumber] = ((_c = infoRequest === null || infoRequest === void 0 ? void 0 : infoRequest.targetChainBlockRanges) === null || _c === void 0 ? void 0 : _c.get(targetChain)) ||
            helpers_1.getBlockRange(targetChainProvider);
        const targetChainStatus = yield helpers_1.getWormholeRelayerInfoBySourceSequence(environment, targetChain, targetChainProvider, sourceChain, ethers_1.BigNumber.from(deliveryLog.sequence), blockStartNumber, blockEndNumber, ((_d = infoRequest === null || infoRequest === void 0 ? void 0 : infoRequest.wormholeRelayerAddresses) === null || _d === void 0 ? void 0 : _d.get(targetChain)) ||
            consts_1.getWormholeRelayerAddress(targetChain, environment));
        return {
            type: structs_1.RelayerPayloadId.Delivery,
            sourceChain: sourceChain,
            sourceTransactionHash: sourceTransaction,
            sourceDeliverySequenceNumber: ethers_1.BigNumber.from(deliveryLog.sequence).toNumber(),
            deliveryInstruction: instruction,
            targetChainStatus,
        };
    });
}
exports.getWormholeRelayerInfo = getWormholeRelayerInfo;
function printWormholeRelayerInfo(info) {
    console.log(stringifyWormholeRelayerInfo(info));
}
exports.printWormholeRelayerInfo = printWormholeRelayerInfo;
function stringifyWormholeRelayerInfo(info, excludeSourceInformation, overrides) {
    let stringifiedInfo = "";
    if (info.type == structs_1.RelayerPayloadId.Delivery &&
        info.deliveryInstruction.targetAddress.toString("hex") !==
            "0000000000000000000000000000000000000000000000000000000000000000") {
        if (!excludeSourceInformation) {
            stringifiedInfo += `Found delivery request in transaction ${info.sourceTransactionHash} on ${info.sourceChain}\nfrom sender ${info.deliveryInstruction.senderAddress.toString("hex")} from ${info.sourceChain} with delivery sequence number ${info.sourceDeliverySequenceNumber}\n`;
        }
        else {
            stringifiedInfo += `Found delivery request from sender ${info.deliveryInstruction.senderAddress.toString("hex")}\n`;
        }
        const numMsgs = info.deliveryInstruction.messageKeys.length;
        const payload = info.deliveryInstruction.payload.toString("hex");
        if (payload.length > 0) {
            stringifiedInfo += `\nPayload to be relayed (as hex string): 0x${payload}`;
        }
        if (numMsgs > 0) {
            stringifiedInfo += `\nThe following ${numMsgs} wormhole messages (VAAs) were ${payload.length > 0 ? "also " : ""}requested to be relayed:\n`;
            stringifiedInfo += info.deliveryInstruction.messageKeys
                .map((msgKey, i) => {
                var _a;
                let result = "";
                if (msgKey.keyType == structs_1.KeyType.VAA) {
                    const vaaKey = structs_1.parseVaaKey(msgKey.key);
                    result += `(VAA ${i}): `;
                    result += `Message from ${vaaKey.chainId ? helpers_1.printChain(vaaKey.chainId) : ""}, with emitter address ${(_a = vaaKey.emitterAddress) === null || _a === void 0 ? void 0 : _a.toString("hex")} and sequence number ${vaaKey.sequence}`;
                }
                else if (msgKey.keyType == structs_1.KeyType.CCTP) {
                    const cctpKey = structs_1.parseCCTPKey(msgKey.key);
                    result += `(CCTP ${i}): `;
                    result += `Transfer from cctp domain ${helpers_1.printChain(cctpKey.domain)}`;
                    result += `, with nonce ${cctpKey.nonce}`;
                }
                else {
                    result += `(Unknown key type${i}): ${msgKey.keyType}`;
                }
                return result;
            })
                .join(",\n");
        }
        if (payload.length == 0 && numMsgs == 0) {
            stringifiedInfo += `\nAn empty payload was requested to be sent`;
        }
        const instruction = info.deliveryInstruction;
        if (overrides) {
            instruction.requestedReceiverValue = overrides.newReceiverValue;
            instruction.encodedExecutionInfo = overrides.newExecutionInfo;
        }
        const targetChainName = __1.CHAIN_ID_TO_NAME[instruction.targetChainId];
        stringifiedInfo += `${numMsgs == 0
            ? payload.length == 0
                ? ""
                : "\n\nPayload was requested to be relayed"
            : "\n\nThese were requested to be sent"} to 0x${instruction.targetAddress.toString("hex")} on ${helpers_1.printChain(instruction.targetChainId)}\n`;
        const totalReceiverValue = instruction.requestedReceiverValue.add(instruction.extraReceiverValue);
        stringifiedInfo += totalReceiverValue.gt(0)
            ? `Amount to pass into target address: ${ethers_1.ethers.utils.formatEther(totalReceiverValue)} of ${targetChainName} currency ${instruction.extraReceiverValue.gt(0)
                ? `\n${ethers_1.ethers.utils.formatEther(instruction.requestedReceiverValue)} requested, ${ethers_1.ethers.utils.formatEther(instruction.extraReceiverValue)} additionally paid for`
                : ""}\n`
            : ``;
        const [executionInfo] = structs_1.parseEVMExecutionInfoV1(instruction.encodedExecutionInfo, 0);
        stringifiedInfo += `Gas limit: ${executionInfo.gasLimit} ${targetChainName} gas\n`;
        const refundAddressChosen = instruction.refundAddress !== instruction.refundDeliveryProvider;
        if (refundAddressChosen) {
            stringifiedInfo += `Refund rate: ${ethers_1.ethers.utils.formatEther(executionInfo.targetChainRefundPerGasUnused)} of ${targetChainName} currency per unit of gas unused\n`;
            stringifiedInfo += `Refund address: ${instruction.refundAddress.toString("hex")}\n`;
        }
        stringifiedInfo += `\n`;
        stringifiedInfo += info.targetChainStatus.events
            .map((e, i) => `Delivery attempt ${i + 1}: ${e.transactionHash
            ? ` ${targetChainName} transaction hash: ${e.transactionHash}`
            : ""}\nStatus: ${e.status}\n${e.revertString
            ? `Failure reason: ${e.gasUsed.eq(executionInfo.gasLimit)
                ? "Gas limit hit"
                : e.revertString}\n`
            : ""}Gas used: ${e.gasUsed.toString()}\nTransaction fee used: ${ethers_1.ethers.utils.formatEther(executionInfo.targetChainRefundPerGasUnused.mul(e.gasUsed))} of ${targetChainName} currency\n${`Refund amount: ${ethers_1.ethers.utils.formatEther(executionInfo.targetChainRefundPerGasUnused.mul(executionInfo.gasLimit.sub(e.gasUsed)))} of ${targetChainName} currency \nRefund status: ${e.refundStatus}\n`}`)
            .join("\n");
    }
    else if (info.type == structs_1.RelayerPayloadId.Delivery &&
        info.deliveryInstruction.targetAddress.toString("hex") ===
            "0000000000000000000000000000000000000000000000000000000000000000") {
        stringifiedInfo += `Found delivery request in transaction ${info.sourceTransactionHash} on ${info.sourceChain}\n`;
        const instruction = info.deliveryInstruction;
        const targetChainName = __1.CHAIN_ID_TO_NAME[instruction.targetChainId];
        stringifiedInfo += `\nA refund of ${ethers_1.ethers.utils.formatEther(instruction.extraReceiverValue)} ${targetChainName} currency was requested to be sent to ${targetChainName}, address 0x${info.deliveryInstruction.refundAddress.toString("hex")}\n\n`;
        stringifiedInfo += info.targetChainStatus.events
            .map((e, i) => `Delivery attempt ${i + 1}: ${e.transactionHash
            ? ` ${targetChainName} transaction hash: ${e.transactionHash}`
            : ""}\nStatus: ${e.refundStatus == structs_1.RefundStatus.RefundSent
            ? "Refund Successful"
            : "Refund Failed"}`)
            .join("\n");
    }
    return stringifiedInfo;
}
exports.stringifyWormholeRelayerInfo = stringifyWormholeRelayerInfo;
