import type { BaseContract, BigNumber, BigNumberish, BytesLike, CallOverrides, PopulatedTransaction, Signer, utils } from "ethers";
import type { FunctionFragment, Result } from "@ethersproject/abi";
import type { Listener, Provider } from "@ethersproject/providers";
import type { TypedEventFilter, TypedEvent, TypedListener, OnEvent, PromiseOrValue } from "./common";
export declare namespace Structs {
    type GuardianSetStruct = {
        keys: PromiseOrValue<string>[];
        expirationTime: PromiseOrValue<BigNumberish>;
    };
    type GuardianSetStructOutput = [string[], number] & {
        keys: string[];
        expirationTime: number;
    };
}
export interface GettersInterface extends utils.Interface {
    functions: {
        "chainId()": FunctionFragment;
        "evmChainId()": FunctionFragment;
        "getCurrentGuardianSetIndex()": FunctionFragment;
        "getGuardianSet(uint32)": FunctionFragment;
        "getGuardianSetExpiry()": FunctionFragment;
        "governanceActionIsConsumed(bytes32)": FunctionFragment;
        "governanceChainId()": FunctionFragment;
        "governanceContract()": FunctionFragment;
        "isFork()": FunctionFragment;
        "isInitialized(address)": FunctionFragment;
        "messageFee()": FunctionFragment;
        "nextSequence(address)": FunctionFragment;
    };
    getFunction(nameOrSignatureOrTopic: "chainId" | "evmChainId" | "getCurrentGuardianSetIndex" | "getGuardianSet" | "getGuardianSetExpiry" | "governanceActionIsConsumed" | "governanceChainId" | "governanceContract" | "isFork" | "isInitialized" | "messageFee" | "nextSequence"): FunctionFragment;
    encodeFunctionData(functionFragment: "chainId", values?: undefined): string;
    encodeFunctionData(functionFragment: "evmChainId", values?: undefined): string;
    encodeFunctionData(functionFragment: "getCurrentGuardianSetIndex", values?: undefined): string;
    encodeFunctionData(functionFragment: "getGuardianSet", values: [PromiseOrValue<BigNumberish>]): string;
    encodeFunctionData(functionFragment: "getGuardianSetExpiry", values?: undefined): string;
    encodeFunctionData(functionFragment: "governanceActionIsConsumed", values: [PromiseOrValue<BytesLike>]): string;
    encodeFunctionData(functionFragment: "governanceChainId", values?: undefined): string;
    encodeFunctionData(functionFragment: "governanceContract", values?: undefined): string;
    encodeFunctionData(functionFragment: "isFork", values?: undefined): string;
    encodeFunctionData(functionFragment: "isInitialized", values: [PromiseOrValue<string>]): string;
    encodeFunctionData(functionFragment: "messageFee", values?: undefined): string;
    encodeFunctionData(functionFragment: "nextSequence", values: [PromiseOrValue<string>]): string;
    decodeFunctionResult(functionFragment: "chainId", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "evmChainId", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "getCurrentGuardianSetIndex", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "getGuardianSet", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "getGuardianSetExpiry", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "governanceActionIsConsumed", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "governanceChainId", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "governanceContract", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "isFork", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "isInitialized", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "messageFee", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "nextSequence", data: BytesLike): Result;
    events: {};
}
export interface Getters extends BaseContract {
    connect(signerOrProvider: Signer | Provider | string): this;
    attach(addressOrName: string): this;
    deployed(): Promise<this>;
    interface: GettersInterface;
    queryFilter<TEvent extends TypedEvent>(event: TypedEventFilter<TEvent>, fromBlockOrBlockhash?: string | number | undefined, toBlock?: string | number | undefined): Promise<Array<TEvent>>;
    listeners<TEvent extends TypedEvent>(eventFilter?: TypedEventFilter<TEvent>): Array<TypedListener<TEvent>>;
    listeners(eventName?: string): Array<Listener>;
    removeAllListeners<TEvent extends TypedEvent>(eventFilter: TypedEventFilter<TEvent>): this;
    removeAllListeners(eventName?: string): this;
    off: OnEvent<this>;
    on: OnEvent<this>;
    once: OnEvent<this>;
    removeListener: OnEvent<this>;
    functions: {
        chainId(overrides?: CallOverrides): Promise<[number]>;
        evmChainId(overrides?: CallOverrides): Promise<[BigNumber]>;
        getCurrentGuardianSetIndex(overrides?: CallOverrides): Promise<[number]>;
        getGuardianSet(index: PromiseOrValue<BigNumberish>, overrides?: CallOverrides): Promise<[Structs.GuardianSetStructOutput]>;
        getGuardianSetExpiry(overrides?: CallOverrides): Promise<[number]>;
        governanceActionIsConsumed(hash: PromiseOrValue<BytesLike>, overrides?: CallOverrides): Promise<[boolean]>;
        governanceChainId(overrides?: CallOverrides): Promise<[number]>;
        governanceContract(overrides?: CallOverrides): Promise<[string]>;
        isFork(overrides?: CallOverrides): Promise<[boolean]>;
        isInitialized(impl: PromiseOrValue<string>, overrides?: CallOverrides): Promise<[boolean]>;
        messageFee(overrides?: CallOverrides): Promise<[BigNumber]>;
        nextSequence(emitter: PromiseOrValue<string>, overrides?: CallOverrides): Promise<[BigNumber]>;
    };
    chainId(overrides?: CallOverrides): Promise<number>;
    evmChainId(overrides?: CallOverrides): Promise<BigNumber>;
    getCurrentGuardianSetIndex(overrides?: CallOverrides): Promise<number>;
    getGuardianSet(index: PromiseOrValue<BigNumberish>, overrides?: CallOverrides): Promise<Structs.GuardianSetStructOutput>;
    getGuardianSetExpiry(overrides?: CallOverrides): Promise<number>;
    governanceActionIsConsumed(hash: PromiseOrValue<BytesLike>, overrides?: CallOverrides): Promise<boolean>;
    governanceChainId(overrides?: CallOverrides): Promise<number>;
    governanceContract(overrides?: CallOverrides): Promise<string>;
    isFork(overrides?: CallOverrides): Promise<boolean>;
    isInitialized(impl: PromiseOrValue<string>, overrides?: CallOverrides): Promise<boolean>;
    messageFee(overrides?: CallOverrides): Promise<BigNumber>;
    nextSequence(emitter: PromiseOrValue<string>, overrides?: CallOverrides): Promise<BigNumber>;
    callStatic: {
        chainId(overrides?: CallOverrides): Promise<number>;
        evmChainId(overrides?: CallOverrides): Promise<BigNumber>;
        getCurrentGuardianSetIndex(overrides?: CallOverrides): Promise<number>;
        getGuardianSet(index: PromiseOrValue<BigNumberish>, overrides?: CallOverrides): Promise<Structs.GuardianSetStructOutput>;
        getGuardianSetExpiry(overrides?: CallOverrides): Promise<number>;
        governanceActionIsConsumed(hash: PromiseOrValue<BytesLike>, overrides?: CallOverrides): Promise<boolean>;
        governanceChainId(overrides?: CallOverrides): Promise<number>;
        governanceContract(overrides?: CallOverrides): Promise<string>;
        isFork(overrides?: CallOverrides): Promise<boolean>;
        isInitialized(impl: PromiseOrValue<string>, overrides?: CallOverrides): Promise<boolean>;
        messageFee(overrides?: CallOverrides): Promise<BigNumber>;
        nextSequence(emitter: PromiseOrValue<string>, overrides?: CallOverrides): Promise<BigNumber>;
    };
    filters: {};
    estimateGas: {
        chainId(overrides?: CallOverrides): Promise<BigNumber>;
        evmChainId(overrides?: CallOverrides): Promise<BigNumber>;
        getCurrentGuardianSetIndex(overrides?: CallOverrides): Promise<BigNumber>;
        getGuardianSet(index: PromiseOrValue<BigNumberish>, overrides?: CallOverrides): Promise<BigNumber>;
        getGuardianSetExpiry(overrides?: CallOverrides): Promise<BigNumber>;
        governanceActionIsConsumed(hash: PromiseOrValue<BytesLike>, overrides?: CallOverrides): Promise<BigNumber>;
        governanceChainId(overrides?: CallOverrides): Promise<BigNumber>;
        governanceContract(overrides?: CallOverrides): Promise<BigNumber>;
        isFork(overrides?: CallOverrides): Promise<BigNumber>;
        isInitialized(impl: PromiseOrValue<string>, overrides?: CallOverrides): Promise<BigNumber>;
        messageFee(overrides?: CallOverrides): Promise<BigNumber>;
        nextSequence(emitter: PromiseOrValue<string>, overrides?: CallOverrides): Promise<BigNumber>;
    };
    populateTransaction: {
        chainId(overrides?: CallOverrides): Promise<PopulatedTransaction>;
        evmChainId(overrides?: CallOverrides): Promise<PopulatedTransaction>;
        getCurrentGuardianSetIndex(overrides?: CallOverrides): Promise<PopulatedTransaction>;
        getGuardianSet(index: PromiseOrValue<BigNumberish>, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        getGuardianSetExpiry(overrides?: CallOverrides): Promise<PopulatedTransaction>;
        governanceActionIsConsumed(hash: PromiseOrValue<BytesLike>, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        governanceChainId(overrides?: CallOverrides): Promise<PopulatedTransaction>;
        governanceContract(overrides?: CallOverrides): Promise<PopulatedTransaction>;
        isFork(overrides?: CallOverrides): Promise<PopulatedTransaction>;
        isInitialized(impl: PromiseOrValue<string>, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        messageFee(overrides?: CallOverrides): Promise<PopulatedTransaction>;
        nextSequence(emitter: PromiseOrValue<string>, overrides?: CallOverrides): Promise<PopulatedTransaction>;
    };
}
