import type { BaseContract, BigNumber, BigNumberish, BytesLike, CallOverrides, ContractTransaction, Overrides, PayableOverrides, PopulatedTransaction, Signer, utils } from "ethers";
import type { FunctionFragment, Result, EventFragment } from "@ethersproject/abi";
import type { Listener, Provider } from "@ethersproject/providers";
import type { TypedEventFilter, TypedEvent, TypedListener, OnEvent, PromiseOrValue } from "./common";
export declare namespace Structs {
    type GuardianSetStruct = {
        keys: PromiseOrValue<string>[];
        expirationTime: PromiseOrValue<BigNumberish>;
    };
    type GuardianSetStructOutput = [string[], number] & {
        keys: string[];
        expirationTime: number;
    };
    type SignatureStruct = {
        r: PromiseOrValue<BytesLike>;
        s: PromiseOrValue<BytesLike>;
        v: PromiseOrValue<BigNumberish>;
        guardianIndex: PromiseOrValue<BigNumberish>;
    };
    type SignatureStructOutput = [string, string, number, number] & {
        r: string;
        s: string;
        v: number;
        guardianIndex: number;
    };
    type VMStruct = {
        version: PromiseOrValue<BigNumberish>;
        timestamp: PromiseOrValue<BigNumberish>;
        nonce: PromiseOrValue<BigNumberish>;
        emitterChainId: PromiseOrValue<BigNumberish>;
        emitterAddress: PromiseOrValue<BytesLike>;
        sequence: PromiseOrValue<BigNumberish>;
        consistencyLevel: PromiseOrValue<BigNumberish>;
        payload: PromiseOrValue<BytesLike>;
        guardianSetIndex: PromiseOrValue<BigNumberish>;
        signatures: Structs.SignatureStruct[];
        hash: PromiseOrValue<BytesLike>;
    };
    type VMStructOutput = [
        number,
        number,
        number,
        number,
        string,
        BigNumber,
        number,
        string,
        number,
        Structs.SignatureStructOutput[],
        string
    ] & {
        version: number;
        timestamp: number;
        nonce: number;
        emitterChainId: number;
        emitterAddress: string;
        sequence: BigNumber;
        consistencyLevel: number;
        payload: string;
        guardianSetIndex: number;
        signatures: Structs.SignatureStructOutput[];
        hash: string;
    };
}
export declare namespace GovernanceStructs {
    type ContractUpgradeStruct = {
        module: PromiseOrValue<BytesLike>;
        action: PromiseOrValue<BigNumberish>;
        chain: PromiseOrValue<BigNumberish>;
        newContract: PromiseOrValue<string>;
    };
    type ContractUpgradeStructOutput = [string, number, number, string] & {
        module: string;
        action: number;
        chain: number;
        newContract: string;
    };
    type GuardianSetUpgradeStruct = {
        module: PromiseOrValue<BytesLike>;
        action: PromiseOrValue<BigNumberish>;
        chain: PromiseOrValue<BigNumberish>;
        newGuardianSet: Structs.GuardianSetStruct;
        newGuardianSetIndex: PromiseOrValue<BigNumberish>;
    };
    type GuardianSetUpgradeStructOutput = [
        string,
        number,
        number,
        Structs.GuardianSetStructOutput,
        number
    ] & {
        module: string;
        action: number;
        chain: number;
        newGuardianSet: Structs.GuardianSetStructOutput;
        newGuardianSetIndex: number;
    };
    type RecoverChainIdStruct = {
        module: PromiseOrValue<BytesLike>;
        action: PromiseOrValue<BigNumberish>;
        evmChainId: PromiseOrValue<BigNumberish>;
        newChainId: PromiseOrValue<BigNumberish>;
    };
    type RecoverChainIdStructOutput = [
        string,
        number,
        BigNumber,
        number
    ] & {
        module: string;
        action: number;
        evmChainId: BigNumber;
        newChainId: number;
    };
    type SetMessageFeeStruct = {
        module: PromiseOrValue<BytesLike>;
        action: PromiseOrValue<BigNumberish>;
        chain: PromiseOrValue<BigNumberish>;
        messageFee: PromiseOrValue<BigNumberish>;
    };
    type SetMessageFeeStructOutput = [
        string,
        number,
        number,
        BigNumber
    ] & {
        module: string;
        action: number;
        chain: number;
        messageFee: BigNumber;
    };
    type TransferFeesStruct = {
        module: PromiseOrValue<BytesLike>;
        action: PromiseOrValue<BigNumberish>;
        chain: PromiseOrValue<BigNumberish>;
        amount: PromiseOrValue<BigNumberish>;
        recipient: PromiseOrValue<BytesLike>;
    };
    type TransferFeesStructOutput = [
        string,
        number,
        number,
        BigNumber,
        string
    ] & {
        module: string;
        action: number;
        chain: number;
        amount: BigNumber;
        recipient: string;
    };
}
export interface ImplementationInterface extends utils.Interface {
    functions: {
        "chainId()": FunctionFragment;
        "evmChainId()": FunctionFragment;
        "getCurrentGuardianSetIndex()": FunctionFragment;
        "getGuardianSet(uint32)": FunctionFragment;
        "getGuardianSetExpiry()": FunctionFragment;
        "governanceActionIsConsumed(bytes32)": FunctionFragment;
        "governanceChainId()": FunctionFragment;
        "governanceContract()": FunctionFragment;
        "initialize()": FunctionFragment;
        "isFork()": FunctionFragment;
        "isInitialized(address)": FunctionFragment;
        "messageFee()": FunctionFragment;
        "nextSequence(address)": FunctionFragment;
        "parseAndVerifyVM(bytes)": FunctionFragment;
        "parseContractUpgrade(bytes)": FunctionFragment;
        "parseGuardianSetUpgrade(bytes)": FunctionFragment;
        "parseRecoverChainId(bytes)": FunctionFragment;
        "parseSetMessageFee(bytes)": FunctionFragment;
        "parseTransferFees(bytes)": FunctionFragment;
        "parseVM(bytes)": FunctionFragment;
        "publishMessage(uint32,bytes,uint8)": FunctionFragment;
        "quorum(uint256)": FunctionFragment;
        "submitContractUpgrade(bytes)": FunctionFragment;
        "submitNewGuardianSet(bytes)": FunctionFragment;
        "submitRecoverChainId(bytes)": FunctionFragment;
        "submitSetMessageFee(bytes)": FunctionFragment;
        "submitTransferFees(bytes)": FunctionFragment;
        "verifySignatures(bytes32,(bytes32,bytes32,uint8,uint8)[],(address[],uint32))": FunctionFragment;
        "verifyVM((uint8,uint32,uint32,uint16,bytes32,uint64,uint8,bytes,uint32,(bytes32,bytes32,uint8,uint8)[],bytes32))": FunctionFragment;
    };
    getFunction(nameOrSignatureOrTopic: "chainId" | "evmChainId" | "getCurrentGuardianSetIndex" | "getGuardianSet" | "getGuardianSetExpiry" | "governanceActionIsConsumed" | "governanceChainId" | "governanceContract" | "initialize" | "isFork" | "isInitialized" | "messageFee" | "nextSequence" | "parseAndVerifyVM" | "parseContractUpgrade" | "parseGuardianSetUpgrade" | "parseRecoverChainId" | "parseSetMessageFee" | "parseTransferFees" | "parseVM" | "publishMessage" | "quorum" | "submitContractUpgrade" | "submitNewGuardianSet" | "submitRecoverChainId" | "submitSetMessageFee" | "submitTransferFees" | "verifySignatures" | "verifyVM"): FunctionFragment;
    encodeFunctionData(functionFragment: "chainId", values?: undefined): string;
    encodeFunctionData(functionFragment: "evmChainId", values?: undefined): string;
    encodeFunctionData(functionFragment: "getCurrentGuardianSetIndex", values?: undefined): string;
    encodeFunctionData(functionFragment: "getGuardianSet", values: [PromiseOrValue<BigNumberish>]): string;
    encodeFunctionData(functionFragment: "getGuardianSetExpiry", values?: undefined): string;
    encodeFunctionData(functionFragment: "governanceActionIsConsumed", values: [PromiseOrValue<BytesLike>]): string;
    encodeFunctionData(functionFragment: "governanceChainId", values?: undefined): string;
    encodeFunctionData(functionFragment: "governanceContract", values?: undefined): string;
    encodeFunctionData(functionFragment: "initialize", values?: undefined): string;
    encodeFunctionData(functionFragment: "isFork", values?: undefined): string;
    encodeFunctionData(functionFragment: "isInitialized", values: [PromiseOrValue<string>]): string;
    encodeFunctionData(functionFragment: "messageFee", values?: undefined): string;
    encodeFunctionData(functionFragment: "nextSequence", values: [PromiseOrValue<string>]): string;
    encodeFunctionData(functionFragment: "parseAndVerifyVM", values: [PromiseOrValue<BytesLike>]): string;
    encodeFunctionData(functionFragment: "parseContractUpgrade", values: [PromiseOrValue<BytesLike>]): string;
    encodeFunctionData(functionFragment: "parseGuardianSetUpgrade", values: [PromiseOrValue<BytesLike>]): string;
    encodeFunctionData(functionFragment: "parseRecoverChainId", values: [PromiseOrValue<BytesLike>]): string;
    encodeFunctionData(functionFragment: "parseSetMessageFee", values: [PromiseOrValue<BytesLike>]): string;
    encodeFunctionData(functionFragment: "parseTransferFees", values: [PromiseOrValue<BytesLike>]): string;
    encodeFunctionData(functionFragment: "parseVM", values: [PromiseOrValue<BytesLike>]): string;
    encodeFunctionData(functionFragment: "publishMessage", values: [
        PromiseOrValue<BigNumberish>,
        PromiseOrValue<BytesLike>,
        PromiseOrValue<BigNumberish>
    ]): string;
    encodeFunctionData(functionFragment: "quorum", values: [PromiseOrValue<BigNumberish>]): string;
    encodeFunctionData(functionFragment: "submitContractUpgrade", values: [PromiseOrValue<BytesLike>]): string;
    encodeFunctionData(functionFragment: "submitNewGuardianSet", values: [PromiseOrValue<BytesLike>]): string;
    encodeFunctionData(functionFragment: "submitRecoverChainId", values: [PromiseOrValue<BytesLike>]): string;
    encodeFunctionData(functionFragment: "submitSetMessageFee", values: [PromiseOrValue<BytesLike>]): string;
    encodeFunctionData(functionFragment: "submitTransferFees", values: [PromiseOrValue<BytesLike>]): string;
    encodeFunctionData(functionFragment: "verifySignatures", values: [
        PromiseOrValue<BytesLike>,
        Structs.SignatureStruct[],
        Structs.GuardianSetStruct
    ]): string;
    encodeFunctionData(functionFragment: "verifyVM", values: [Structs.VMStruct]): string;
    decodeFunctionResult(functionFragment: "chainId", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "evmChainId", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "getCurrentGuardianSetIndex", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "getGuardianSet", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "getGuardianSetExpiry", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "governanceActionIsConsumed", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "governanceChainId", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "governanceContract", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "initialize", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "isFork", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "isInitialized", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "messageFee", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "nextSequence", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "parseAndVerifyVM", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "parseContractUpgrade", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "parseGuardianSetUpgrade", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "parseRecoverChainId", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "parseSetMessageFee", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "parseTransferFees", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "parseVM", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "publishMessage", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "quorum", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "submitContractUpgrade", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "submitNewGuardianSet", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "submitRecoverChainId", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "submitSetMessageFee", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "submitTransferFees", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "verifySignatures", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "verifyVM", data: BytesLike): Result;
    events: {
        "AdminChanged(address,address)": EventFragment;
        "BeaconUpgraded(address)": EventFragment;
        "ContractUpgraded(address,address)": EventFragment;
        "GuardianSetAdded(uint32)": EventFragment;
        "LogMessagePublished(address,uint64,uint32,bytes,uint8)": EventFragment;
        "Upgraded(address)": EventFragment;
    };
    getEvent(nameOrSignatureOrTopic: "AdminChanged"): EventFragment;
    getEvent(nameOrSignatureOrTopic: "BeaconUpgraded"): EventFragment;
    getEvent(nameOrSignatureOrTopic: "ContractUpgraded"): EventFragment;
    getEvent(nameOrSignatureOrTopic: "GuardianSetAdded"): EventFragment;
    getEvent(nameOrSignatureOrTopic: "LogMessagePublished"): EventFragment;
    getEvent(nameOrSignatureOrTopic: "Upgraded"): EventFragment;
}
export interface AdminChangedEventObject {
    previousAdmin: string;
    newAdmin: string;
}
export declare type AdminChangedEvent = TypedEvent<[
    string,
    string
], AdminChangedEventObject>;
export declare type AdminChangedEventFilter = TypedEventFilter<AdminChangedEvent>;
export interface BeaconUpgradedEventObject {
    beacon: string;
}
export declare type BeaconUpgradedEvent = TypedEvent<[
    string
], BeaconUpgradedEventObject>;
export declare type BeaconUpgradedEventFilter = TypedEventFilter<BeaconUpgradedEvent>;
export interface ContractUpgradedEventObject {
    oldContract: string;
    newContract: string;
}
export declare type ContractUpgradedEvent = TypedEvent<[
    string,
    string
], ContractUpgradedEventObject>;
export declare type ContractUpgradedEventFilter = TypedEventFilter<ContractUpgradedEvent>;
export interface GuardianSetAddedEventObject {
    index: number;
}
export declare type GuardianSetAddedEvent = TypedEvent<[
    number
], GuardianSetAddedEventObject>;
export declare type GuardianSetAddedEventFilter = TypedEventFilter<GuardianSetAddedEvent>;
export interface LogMessagePublishedEventObject {
    sender: string;
    sequence: BigNumber;
    nonce: number;
    payload: string;
    consistencyLevel: number;
}
export declare type LogMessagePublishedEvent = TypedEvent<[
    string,
    BigNumber,
    number,
    string,
    number
], LogMessagePublishedEventObject>;
export declare type LogMessagePublishedEventFilter = TypedEventFilter<LogMessagePublishedEvent>;
export interface UpgradedEventObject {
    implementation: string;
}
export declare type UpgradedEvent = TypedEvent<[string], UpgradedEventObject>;
export declare type UpgradedEventFilter = TypedEventFilter<UpgradedEvent>;
export interface Implementation extends BaseContract {
    connect(signerOrProvider: Signer | Provider | string): this;
    attach(addressOrName: string): this;
    deployed(): Promise<this>;
    interface: ImplementationInterface;
    queryFilter<TEvent extends TypedEvent>(event: TypedEventFilter<TEvent>, fromBlockOrBlockhash?: string | number | undefined, toBlock?: string | number | undefined): Promise<Array<TEvent>>;
    listeners<TEvent extends TypedEvent>(eventFilter?: TypedEventFilter<TEvent>): Array<TypedListener<TEvent>>;
    listeners(eventName?: string): Array<Listener>;
    removeAllListeners<TEvent extends TypedEvent>(eventFilter: TypedEventFilter<TEvent>): this;
    removeAllListeners(eventName?: string): this;
    off: OnEvent<this>;
    on: OnEvent<this>;
    once: OnEvent<this>;
    removeListener: OnEvent<this>;
    functions: {
        chainId(overrides?: CallOverrides): Promise<[number]>;
        evmChainId(overrides?: CallOverrides): Promise<[BigNumber]>;
        getCurrentGuardianSetIndex(overrides?: CallOverrides): Promise<[number]>;
        getGuardianSet(index: PromiseOrValue<BigNumberish>, overrides?: CallOverrides): Promise<[Structs.GuardianSetStructOutput]>;
        getGuardianSetExpiry(overrides?: CallOverrides): Promise<[number]>;
        governanceActionIsConsumed(hash: PromiseOrValue<BytesLike>, overrides?: CallOverrides): Promise<[boolean]>;
        governanceChainId(overrides?: CallOverrides): Promise<[number]>;
        governanceContract(overrides?: CallOverrides): Promise<[string]>;
        initialize(overrides?: Overrides & {
            from?: PromiseOrValue<string>;
        }): Promise<ContractTransaction>;
        isFork(overrides?: CallOverrides): Promise<[boolean]>;
        isInitialized(impl: PromiseOrValue<string>, overrides?: CallOverrides): Promise<[boolean]>;
        messageFee(overrides?: CallOverrides): Promise<[BigNumber]>;
        nextSequence(emitter: PromiseOrValue<string>, overrides?: CallOverrides): Promise<[BigNumber]>;
        parseAndVerifyVM(encodedVM: PromiseOrValue<BytesLike>, overrides?: CallOverrides): Promise<[
            Structs.VMStructOutput,
            boolean,
            string
        ] & {
            vm: Structs.VMStructOutput;
            valid: boolean;
            reason: string;
        }>;
        parseContractUpgrade(encodedUpgrade: PromiseOrValue<BytesLike>, overrides?: CallOverrides): Promise<[
            GovernanceStructs.ContractUpgradeStructOutput
        ] & {
            cu: GovernanceStructs.ContractUpgradeStructOutput;
        }>;
        parseGuardianSetUpgrade(encodedUpgrade: PromiseOrValue<BytesLike>, overrides?: CallOverrides): Promise<[
            GovernanceStructs.GuardianSetUpgradeStructOutput
        ] & {
            gsu: GovernanceStructs.GuardianSetUpgradeStructOutput;
        }>;
        parseRecoverChainId(encodedRecoverChainId: PromiseOrValue<BytesLike>, overrides?: CallOverrides): Promise<[
            GovernanceStructs.RecoverChainIdStructOutput
        ] & {
            rci: GovernanceStructs.RecoverChainIdStructOutput;
        }>;
        parseSetMessageFee(encodedSetMessageFee: PromiseOrValue<BytesLike>, overrides?: CallOverrides): Promise<[
            GovernanceStructs.SetMessageFeeStructOutput
        ] & {
            smf: GovernanceStructs.SetMessageFeeStructOutput;
        }>;
        parseTransferFees(encodedTransferFees: PromiseOrValue<BytesLike>, overrides?: CallOverrides): Promise<[
            GovernanceStructs.TransferFeesStructOutput
        ] & {
            tf: GovernanceStructs.TransferFeesStructOutput;
        }>;
        parseVM(encodedVM: PromiseOrValue<BytesLike>, overrides?: CallOverrides): Promise<[Structs.VMStructOutput] & {
            vm: Structs.VMStructOutput;
        }>;
        publishMessage(nonce: PromiseOrValue<BigNumberish>, payload: PromiseOrValue<BytesLike>, consistencyLevel: PromiseOrValue<BigNumberish>, overrides?: PayableOverrides & {
            from?: PromiseOrValue<string>;
        }): Promise<ContractTransaction>;
        quorum(numGuardians: PromiseOrValue<BigNumberish>, overrides?: CallOverrides): Promise<[BigNumber] & {
            numSignaturesRequiredForQuorum: BigNumber;
        }>;
        submitContractUpgrade(_vm: PromiseOrValue<BytesLike>, overrides?: Overrides & {
            from?: PromiseOrValue<string>;
        }): Promise<ContractTransaction>;
        submitNewGuardianSet(_vm: PromiseOrValue<BytesLike>, overrides?: Overrides & {
            from?: PromiseOrValue<string>;
        }): Promise<ContractTransaction>;
        submitRecoverChainId(_vm: PromiseOrValue<BytesLike>, overrides?: Overrides & {
            from?: PromiseOrValue<string>;
        }): Promise<ContractTransaction>;
        submitSetMessageFee(_vm: PromiseOrValue<BytesLike>, overrides?: Overrides & {
            from?: PromiseOrValue<string>;
        }): Promise<ContractTransaction>;
        submitTransferFees(_vm: PromiseOrValue<BytesLike>, overrides?: Overrides & {
            from?: PromiseOrValue<string>;
        }): Promise<ContractTransaction>;
        verifySignatures(hash: PromiseOrValue<BytesLike>, signatures: Structs.SignatureStruct[], guardianSet: Structs.GuardianSetStruct, overrides?: CallOverrides): Promise<[boolean, string] & {
            valid: boolean;
            reason: string;
        }>;
        verifyVM(vm: Structs.VMStruct, overrides?: CallOverrides): Promise<[boolean, string] & {
            valid: boolean;
            reason: string;
        }>;
    };
    chainId(overrides?: CallOverrides): Promise<number>;
    evmChainId(overrides?: CallOverrides): Promise<BigNumber>;
    getCurrentGuardianSetIndex(overrides?: CallOverrides): Promise<number>;
    getGuardianSet(index: PromiseOrValue<BigNumberish>, overrides?: CallOverrides): Promise<Structs.GuardianSetStructOutput>;
    getGuardianSetExpiry(overrides?: CallOverrides): Promise<number>;
    governanceActionIsConsumed(hash: PromiseOrValue<BytesLike>, overrides?: CallOverrides): Promise<boolean>;
    governanceChainId(overrides?: CallOverrides): Promise<number>;
    governanceContract(overrides?: CallOverrides): Promise<string>;
    initialize(overrides?: Overrides & {
        from?: PromiseOrValue<string>;
    }): Promise<ContractTransaction>;
    isFork(overrides?: CallOverrides): Promise<boolean>;
    isInitialized(impl: PromiseOrValue<string>, overrides?: CallOverrides): Promise<boolean>;
    messageFee(overrides?: CallOverrides): Promise<BigNumber>;
    nextSequence(emitter: PromiseOrValue<string>, overrides?: CallOverrides): Promise<BigNumber>;
    parseAndVerifyVM(encodedVM: PromiseOrValue<BytesLike>, overrides?: CallOverrides): Promise<[
        Structs.VMStructOutput,
        boolean,
        string
    ] & {
        vm: Structs.VMStructOutput;
        valid: boolean;
        reason: string;
    }>;
    parseContractUpgrade(encodedUpgrade: PromiseOrValue<BytesLike>, overrides?: CallOverrides): Promise<GovernanceStructs.ContractUpgradeStructOutput>;
    parseGuardianSetUpgrade(encodedUpgrade: PromiseOrValue<BytesLike>, overrides?: CallOverrides): Promise<GovernanceStructs.GuardianSetUpgradeStructOutput>;
    parseRecoverChainId(encodedRecoverChainId: PromiseOrValue<BytesLike>, overrides?: CallOverrides): Promise<GovernanceStructs.RecoverChainIdStructOutput>;
    parseSetMessageFee(encodedSetMessageFee: PromiseOrValue<BytesLike>, overrides?: CallOverrides): Promise<GovernanceStructs.SetMessageFeeStructOutput>;
    parseTransferFees(encodedTransferFees: PromiseOrValue<BytesLike>, overrides?: CallOverrides): Promise<GovernanceStructs.TransferFeesStructOutput>;
    parseVM(encodedVM: PromiseOrValue<BytesLike>, overrides?: CallOverrides): Promise<Structs.VMStructOutput>;
    publishMessage(nonce: PromiseOrValue<BigNumberish>, payload: PromiseOrValue<BytesLike>, consistencyLevel: PromiseOrValue<BigNumberish>, overrides?: PayableOverrides & {
        from?: PromiseOrValue<string>;
    }): Promise<ContractTransaction>;
    quorum(numGuardians: PromiseOrValue<BigNumberish>, overrides?: CallOverrides): Promise<BigNumber>;
    submitContractUpgrade(_vm: PromiseOrValue<BytesLike>, overrides?: Overrides & {
        from?: PromiseOrValue<string>;
    }): Promise<ContractTransaction>;
    submitNewGuardianSet(_vm: PromiseOrValue<BytesLike>, overrides?: Overrides & {
        from?: PromiseOrValue<string>;
    }): Promise<ContractTransaction>;
    submitRecoverChainId(_vm: PromiseOrValue<BytesLike>, overrides?: Overrides & {
        from?: PromiseOrValue<string>;
    }): Promise<ContractTransaction>;
    submitSetMessageFee(_vm: PromiseOrValue<BytesLike>, overrides?: Overrides & {
        from?: PromiseOrValue<string>;
    }): Promise<ContractTransaction>;
    submitTransferFees(_vm: PromiseOrValue<BytesLike>, overrides?: Overrides & {
        from?: PromiseOrValue<string>;
    }): Promise<ContractTransaction>;
    verifySignatures(hash: PromiseOrValue<BytesLike>, signatures: Structs.SignatureStruct[], guardianSet: Structs.GuardianSetStruct, overrides?: CallOverrides): Promise<[boolean, string] & {
        valid: boolean;
        reason: string;
    }>;
    verifyVM(vm: Structs.VMStruct, overrides?: CallOverrides): Promise<[boolean, string] & {
        valid: boolean;
        reason: string;
    }>;
    callStatic: {
        chainId(overrides?: CallOverrides): Promise<number>;
        evmChainId(overrides?: CallOverrides): Promise<BigNumber>;
        getCurrentGuardianSetIndex(overrides?: CallOverrides): Promise<number>;
        getGuardianSet(index: PromiseOrValue<BigNumberish>, overrides?: CallOverrides): Promise<Structs.GuardianSetStructOutput>;
        getGuardianSetExpiry(overrides?: CallOverrides): Promise<number>;
        governanceActionIsConsumed(hash: PromiseOrValue<BytesLike>, overrides?: CallOverrides): Promise<boolean>;
        governanceChainId(overrides?: CallOverrides): Promise<number>;
        governanceContract(overrides?: CallOverrides): Promise<string>;
        initialize(overrides?: CallOverrides): Promise<void>;
        isFork(overrides?: CallOverrides): Promise<boolean>;
        isInitialized(impl: PromiseOrValue<string>, overrides?: CallOverrides): Promise<boolean>;
        messageFee(overrides?: CallOverrides): Promise<BigNumber>;
        nextSequence(emitter: PromiseOrValue<string>, overrides?: CallOverrides): Promise<BigNumber>;
        parseAndVerifyVM(encodedVM: PromiseOrValue<BytesLike>, overrides?: CallOverrides): Promise<[
            Structs.VMStructOutput,
            boolean,
            string
        ] & {
            vm: Structs.VMStructOutput;
            valid: boolean;
            reason: string;
        }>;
        parseContractUpgrade(encodedUpgrade: PromiseOrValue<BytesLike>, overrides?: CallOverrides): Promise<GovernanceStructs.ContractUpgradeStructOutput>;
        parseGuardianSetUpgrade(encodedUpgrade: PromiseOrValue<BytesLike>, overrides?: CallOverrides): Promise<GovernanceStructs.GuardianSetUpgradeStructOutput>;
        parseRecoverChainId(encodedRecoverChainId: PromiseOrValue<BytesLike>, overrides?: CallOverrides): Promise<GovernanceStructs.RecoverChainIdStructOutput>;
        parseSetMessageFee(encodedSetMessageFee: PromiseOrValue<BytesLike>, overrides?: CallOverrides): Promise<GovernanceStructs.SetMessageFeeStructOutput>;
        parseTransferFees(encodedTransferFees: PromiseOrValue<BytesLike>, overrides?: CallOverrides): Promise<GovernanceStructs.TransferFeesStructOutput>;
        parseVM(encodedVM: PromiseOrValue<BytesLike>, overrides?: CallOverrides): Promise<Structs.VMStructOutput>;
        publishMessage(nonce: PromiseOrValue<BigNumberish>, payload: PromiseOrValue<BytesLike>, consistencyLevel: PromiseOrValue<BigNumberish>, overrides?: CallOverrides): Promise<BigNumber>;
        quorum(numGuardians: PromiseOrValue<BigNumberish>, overrides?: CallOverrides): Promise<BigNumber>;
        submitContractUpgrade(_vm: PromiseOrValue<BytesLike>, overrides?: CallOverrides): Promise<void>;
        submitNewGuardianSet(_vm: PromiseOrValue<BytesLike>, overrides?: CallOverrides): Promise<void>;
        submitRecoverChainId(_vm: PromiseOrValue<BytesLike>, overrides?: CallOverrides): Promise<void>;
        submitSetMessageFee(_vm: PromiseOrValue<BytesLike>, overrides?: CallOverrides): Promise<void>;
        submitTransferFees(_vm: PromiseOrValue<BytesLike>, overrides?: CallOverrides): Promise<void>;
        verifySignatures(hash: PromiseOrValue<BytesLike>, signatures: Structs.SignatureStruct[], guardianSet: Structs.GuardianSetStruct, overrides?: CallOverrides): Promise<[boolean, string] & {
            valid: boolean;
            reason: string;
        }>;
        verifyVM(vm: Structs.VMStruct, overrides?: CallOverrides): Promise<[boolean, string] & {
            valid: boolean;
            reason: string;
        }>;
    };
    filters: {
        "AdminChanged(address,address)"(previousAdmin?: null, newAdmin?: null): AdminChangedEventFilter;
        AdminChanged(previousAdmin?: null, newAdmin?: null): AdminChangedEventFilter;
        "BeaconUpgraded(address)"(beacon?: PromiseOrValue<string> | null): BeaconUpgradedEventFilter;
        BeaconUpgraded(beacon?: PromiseOrValue<string> | null): BeaconUpgradedEventFilter;
        "ContractUpgraded(address,address)"(oldContract?: PromiseOrValue<string> | null, newContract?: PromiseOrValue<string> | null): ContractUpgradedEventFilter;
        ContractUpgraded(oldContract?: PromiseOrValue<string> | null, newContract?: PromiseOrValue<string> | null): ContractUpgradedEventFilter;
        "GuardianSetAdded(uint32)"(index?: PromiseOrValue<BigNumberish> | null): GuardianSetAddedEventFilter;
        GuardianSetAdded(index?: PromiseOrValue<BigNumberish> | null): GuardianSetAddedEventFilter;
        "LogMessagePublished(address,uint64,uint32,bytes,uint8)"(sender?: PromiseOrValue<string> | null, sequence?: null, nonce?: null, payload?: null, consistencyLevel?: null): LogMessagePublishedEventFilter;
        LogMessagePublished(sender?: PromiseOrValue<string> | null, sequence?: null, nonce?: null, payload?: null, consistencyLevel?: null): LogMessagePublishedEventFilter;
        "Upgraded(address)"(implementation?: PromiseOrValue<string> | null): UpgradedEventFilter;
        Upgraded(implementation?: PromiseOrValue<string> | null): UpgradedEventFilter;
    };
    estimateGas: {
        chainId(overrides?: CallOverrides): Promise<BigNumber>;
        evmChainId(overrides?: CallOverrides): Promise<BigNumber>;
        getCurrentGuardianSetIndex(overrides?: CallOverrides): Promise<BigNumber>;
        getGuardianSet(index: PromiseOrValue<BigNumberish>, overrides?: CallOverrides): Promise<BigNumber>;
        getGuardianSetExpiry(overrides?: CallOverrides): Promise<BigNumber>;
        governanceActionIsConsumed(hash: PromiseOrValue<BytesLike>, overrides?: CallOverrides): Promise<BigNumber>;
        governanceChainId(overrides?: CallOverrides): Promise<BigNumber>;
        governanceContract(overrides?: CallOverrides): Promise<BigNumber>;
        initialize(overrides?: Overrides & {
            from?: PromiseOrValue<string>;
        }): Promise<BigNumber>;
        isFork(overrides?: CallOverrides): Promise<BigNumber>;
        isInitialized(impl: PromiseOrValue<string>, overrides?: CallOverrides): Promise<BigNumber>;
        messageFee(overrides?: CallOverrides): Promise<BigNumber>;
        nextSequence(emitter: PromiseOrValue<string>, overrides?: CallOverrides): Promise<BigNumber>;
        parseAndVerifyVM(encodedVM: PromiseOrValue<BytesLike>, overrides?: CallOverrides): Promise<BigNumber>;
        parseContractUpgrade(encodedUpgrade: PromiseOrValue<BytesLike>, overrides?: CallOverrides): Promise<BigNumber>;
        parseGuardianSetUpgrade(encodedUpgrade: PromiseOrValue<BytesLike>, overrides?: CallOverrides): Promise<BigNumber>;
        parseRecoverChainId(encodedRecoverChainId: PromiseOrValue<BytesLike>, overrides?: CallOverrides): Promise<BigNumber>;
        parseSetMessageFee(encodedSetMessageFee: PromiseOrValue<BytesLike>, overrides?: CallOverrides): Promise<BigNumber>;
        parseTransferFees(encodedTransferFees: PromiseOrValue<BytesLike>, overrides?: CallOverrides): Promise<BigNumber>;
        parseVM(encodedVM: PromiseOrValue<BytesLike>, overrides?: CallOverrides): Promise<BigNumber>;
        publishMessage(nonce: PromiseOrValue<BigNumberish>, payload: PromiseOrValue<BytesLike>, consistencyLevel: PromiseOrValue<BigNumberish>, overrides?: PayableOverrides & {
            from?: PromiseOrValue<string>;
        }): Promise<BigNumber>;
        quorum(numGuardians: PromiseOrValue<BigNumberish>, overrides?: CallOverrides): Promise<BigNumber>;
        submitContractUpgrade(_vm: PromiseOrValue<BytesLike>, overrides?: Overrides & {
            from?: PromiseOrValue<string>;
        }): Promise<BigNumber>;
        submitNewGuardianSet(_vm: PromiseOrValue<BytesLike>, overrides?: Overrides & {
            from?: PromiseOrValue<string>;
        }): Promise<BigNumber>;
        submitRecoverChainId(_vm: PromiseOrValue<BytesLike>, overrides?: Overrides & {
            from?: PromiseOrValue<string>;
        }): Promise<BigNumber>;
        submitSetMessageFee(_vm: PromiseOrValue<BytesLike>, overrides?: Overrides & {
            from?: PromiseOrValue<string>;
        }): Promise<BigNumber>;
        submitTransferFees(_vm: PromiseOrValue<BytesLike>, overrides?: Overrides & {
            from?: PromiseOrValue<string>;
        }): Promise<BigNumber>;
        verifySignatures(hash: PromiseOrValue<BytesLike>, signatures: Structs.SignatureStruct[], guardianSet: Structs.GuardianSetStruct, overrides?: CallOverrides): Promise<BigNumber>;
        verifyVM(vm: Structs.VMStruct, overrides?: CallOverrides): Promise<BigNumber>;
    };
    populateTransaction: {
        chainId(overrides?: CallOverrides): Promise<PopulatedTransaction>;
        evmChainId(overrides?: CallOverrides): Promise<PopulatedTransaction>;
        getCurrentGuardianSetIndex(overrides?: CallOverrides): Promise<PopulatedTransaction>;
        getGuardianSet(index: PromiseOrValue<BigNumberish>, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        getGuardianSetExpiry(overrides?: CallOverrides): Promise<PopulatedTransaction>;
        governanceActionIsConsumed(hash: PromiseOrValue<BytesLike>, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        governanceChainId(overrides?: CallOverrides): Promise<PopulatedTransaction>;
        governanceContract(overrides?: CallOverrides): Promise<PopulatedTransaction>;
        initialize(overrides?: Overrides & {
            from?: PromiseOrValue<string>;
        }): Promise<PopulatedTransaction>;
        isFork(overrides?: CallOverrides): Promise<PopulatedTransaction>;
        isInitialized(impl: PromiseOrValue<string>, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        messageFee(overrides?: CallOverrides): Promise<PopulatedTransaction>;
        nextSequence(emitter: PromiseOrValue<string>, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        parseAndVerifyVM(encodedVM: PromiseOrValue<BytesLike>, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        parseContractUpgrade(encodedUpgrade: PromiseOrValue<BytesLike>, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        parseGuardianSetUpgrade(encodedUpgrade: PromiseOrValue<BytesLike>, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        parseRecoverChainId(encodedRecoverChainId: PromiseOrValue<BytesLike>, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        parseSetMessageFee(encodedSetMessageFee: PromiseOrValue<BytesLike>, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        parseTransferFees(encodedTransferFees: PromiseOrValue<BytesLike>, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        parseVM(encodedVM: PromiseOrValue<BytesLike>, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        publishMessage(nonce: PromiseOrValue<BigNumberish>, payload: PromiseOrValue<BytesLike>, consistencyLevel: PromiseOrValue<BigNumberish>, overrides?: PayableOverrides & {
            from?: PromiseOrValue<string>;
        }): Promise<PopulatedTransaction>;
        quorum(numGuardians: PromiseOrValue<BigNumberish>, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        submitContractUpgrade(_vm: PromiseOrValue<BytesLike>, overrides?: Overrides & {
            from?: PromiseOrValue<string>;
        }): Promise<PopulatedTransaction>;
        submitNewGuardianSet(_vm: PromiseOrValue<BytesLike>, overrides?: Overrides & {
            from?: PromiseOrValue<string>;
        }): Promise<PopulatedTransaction>;
        submitRecoverChainId(_vm: PromiseOrValue<BytesLike>, overrides?: Overrides & {
            from?: PromiseOrValue<string>;
        }): Promise<PopulatedTransaction>;
        submitSetMessageFee(_vm: PromiseOrValue<BytesLike>, overrides?: Overrides & {
            from?: PromiseOrValue<string>;
        }): Promise<PopulatedTransaction>;
        submitTransferFees(_vm: PromiseOrValue<BytesLike>, overrides?: Overrides & {
            from?: PromiseOrValue<string>;
        }): Promise<PopulatedTransaction>;
        verifySignatures(hash: PromiseOrValue<BytesLike>, signatures: Structs.SignatureStruct[], guardianSet: Structs.GuardianSetStruct, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        verifyVM(vm: Structs.VMStruct, overrides?: CallOverrides): Promise<PopulatedTransaction>;
    };
}
